@@ -144,7 +144,7 @@ uint32_t inhibit_request(const char *sender, const char *app_name)
     {
         app = g_malloc(sizeof(*app));
         app->cookies = g_array_new(0, 0, sizeof(uint32_t));
-        app->ignored = g_hash_table_contains(ignored, app_name);
+        app->ignored = g_hash_table_contains(ignored, app_name) || g_hash_table_contains(ignored, "*");
         g_hash_table_insert(apps, g_strdup(sender), app);
     }
     if (should_disable_screensaver())
@@ -152,13 +152,14 @@ uint32_t inhibit_request(const char *sender, const char *app_name)
     int i;
     for (i=0; i<app->cookies->len; i++)
     {
-        if (i != g_array_index(app->cookies, uint32_t, i))
+        if (i + 1 != g_array_index(app->cookies, uint32_t, i))
         {
             break;
         }
     }
-    g_array_insert_val(app->cookies, i, i);
-    return i;
+    uint32_t cookie = i + 1;
+    g_array_insert_val(app->cookies, i, cookie);
+    return cookie;
 }
 
 void handle_inhibit(DBusConnection *conn, DBusMessage *msg)
@@ -327,7 +328,7 @@ int main(int argc, char *argv[])
     }
     if (version)
     {
-        printf("xssproxy version 1.1.1\n");
+        printf("xssproxy version 1.1.2\n");
         exit(0);
     }
 
